package com.muyu.enterprise.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.enterprise.mapper.MessageValueMapper;
import com.muyu.enterprise.service.MessageValueService;
import com.muyu.domain.MessageValue;
import com.muyu.domain.req.MessageValueReq;
import com.muyu.domain.resp.MessageValueListResp;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @Author: LiDongJia
 * @Package: com.muyu.car.service.impl
 * @Project: 2112-car-cloud-server
 * @name: MessageValueServiceImpl
 * @Date: 2024/9/19  15:48
 * @Description: 报文数据业务层
 */
@Log4j2
@Service
public class MessageValueServiceImpl
        extends ServiceImpl<MessageValueMapper, MessageValue>
        implements MessageValueService {

    @Autowired
    private MessageValueMapper messageValueMapper;

    public MessageValueServiceImpl(MessageValueMapper messageValueMapper) {
        this.messageValueMapper = messageValueMapper;
    }

    @Override
    public List<MessageValueListResp> findAll(MessageValueReq messageValueReq) {
        LambdaQueryWrapper<MessageValue> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(
                MessageValue::getTemplateId, messageValueReq.getMessageTemplateId()
        );
        queryWrapper.eq(
                MessageValue::getMessageType, messageValueReq.getMessageType()
        );
        List<MessageValue> list = this.list(queryWrapper);
        return list.stream()
                .map(messageValue -> MessageValueListResp.valueBuild(
                                messageValue
                        )
                ).collect(Collectors.toList());
//        ).list;
    }

    /**
     * 根据报文模版id获取报文模板列表
     * @param templateId 报文模版id
     * @return 报文模板列表
     */
    @Override
    public List<MessageValueListResp> findByTemplateId(Long templateId) {
        LambdaQueryWrapper<MessageValue> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(MessageValue::getTemplateId, templateId);
        List<MessageValue> list = this.list(queryWrapper);
        return list.stream()
                .map(messageValue -> MessageValueListResp.valueBuild(
                                messageValue
                        )
                ).collect(Collectors.toList());
    }


//    @Override
//    public JSONObject analysis(String testStr) {
//
//        if (testStr.length() < 18){
//            throw new RuntimeException("报文格式不正确");
//        }
//        //根据空格切割数据
//        String[] hexArray = testStr.split(" ");
//        StringBuilder result = new StringBuilder();
//        for (String hex : hexArray) {
//            int decimal = Integer.parseInt(hex, 16);
//            result.append((char) decimal);
//        }
//        log.info(result);
//        //取出车辆VIN码
//        String vehicleVin = result.substring(1, 18);
//        log.info("车辆VIN:" + vehicleVin);
//        //根据车辆VIN码, 查找到报文模版id
//        Long templateId = messageValueMapper.getTemplateId(vehicleVin);
//        log.info("模版id:" + templateId);
//        //获取到报文模版的列表
//        List<MessageValueListResp> templateList = messageValueMapper.getTemplateList(templateId);
//        //存储报文模板解析后数据
//        JSONObject jsonObject = new JSONObject();
//        for (MessageValueListResp messageValue : templateList) {
//            //起始位下标
//            Integer startIndex = messageValue.getMessageStartIndex() - 1;
//            //截止位下标
//            Integer endIndex = messageValue.getMessageEndIndex();
//            //根据报文模版截取数据
//            String value = result.substring(startIndex, endIndex);
//            //存入数据
//            jsonObject.put(messageValue.getMessageLabel(), value);
//        }
//        for (Map.Entry<String, Object> stringObjectEntry : jsonObject) {
//            log.info(stringObjectEntry.getKey() + ":" + stringObjectEntry.getValue());
//        }
//        return jsonObject;
//    }
}
