package com.muyu.cloud.protocol.parsing.feign;

import com.muyu.common.core.domain.Result;
import com.muyu.domain.resp.MessageValueListResp;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.List;

/**
 * @Author: LiDongJia
 * @Package: com.muyu.cloud.protocol.parsing.feign
 * @Project: 2112-car-cloud-server
 * @name: RemoteServiceClient
 * @Date: 2024/9/28  14:49
 * @Description: 远程调用接口
 */
@FeignClient(name = "cloud-car")
public interface RemoteServiceClient {

    /**
     * 通过车辆vin码查询模板id
     * @param vehicleVin
     * @return
     */
    @GetMapping("/vehicleManage/findByVehicleVin/{vehicleVin}")
    @Operation(description = "通过车辆vin码查询模板id")
    public Result<Long> findByVehicleVin(@PathVariable("vehicleVin") String vehicleVin);

    /**
     * 根据报文模版id查询报文数据
     * @param templateId
     * @return
     */
    @GetMapping("/messageValue/findByTemplateId/{templateId}")
    @Operation(summary = "根据报文模版id查询报文数据", description = "根据报文模版id查询报文数据")
    public Result<List<MessageValueListResp>> findByTemplateId(@PathVariable("templateId") Long templateId);
}
