package com.muyu.cloud.protocol.parsing.feign.factory;

import com.muyu.cloud.protocol.parsing.feign.RemoteServiceClient;
import com.muyu.common.core.domain.Result;
import com.muyu.domain.resp.MessageValueListResp;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;

import java.util.List;

/**
 * 报文模版对象服务降级处理
 * @Author：李庆帅
 * @Package：com.muyu.analysis.parsing.remote.factory
 * @Project：cloud-server
 * @name：RemoteServiceClientFactory
 * @Date：2024/9/28 21:16
 */
public class RemoteServiceClientFactory implements FallbackFactory<RemoteServiceClient>
{
    private static final Logger log = LoggerFactory.getLogger(com.muyu.cloud.protocol.parsing.feign.factory.RemoteServiceClientFactory.class);

    @Override
    public RemoteServiceClient create(Throwable throwable) {
        log.error("报文模版传参调用失败:{}", throwable.getMessage());
        return new RemoteServiceClient() {

            @Override
            public Result<Long> findByVehicleVin(String vehicleVin) {
                return Result.success(Long.valueOf(vehicleVin));
            }

            @Override
            public Result<List<MessageValueListResp>> findByTemplateId(Long templateId) {
                return null;
            }
        };
    }
}
